Approximates the adjustement factor described in Bodnar, Dickhaus (2014) using a Monte Carlo integration.
ac_fdr.calc_delta(cop, m, m0, alpha = 0.05, num.reps = 1e+05,
calc.var = FALSE)The copula
The number of hypotheses
A reasonable lower bound for the number of true hypotheses
the desired significance level
The number of Monte Carlo simulations to use
Additionaly calculate the variance (mostly for the examples)
T. Bodnar and T. Dickhaus (2014). False discovery rate control under Archimedean copula. Electronic Journal of Statistics Volume 8, Number 2 (2014), 2207-2241.